@@ -9,7 +9,7 @@ function(x=NULL, data=mydata, n.cat=getOption("n.cat"),
     col.reg="snow2", over.grid=FALSE,
     cex.axis=.85, col.axis="gray30", col.ticks="gray30",
 
-    breaks="Sturges", bin.start=NULL, bin.width=NULL,
+    breaks="Sturges", bin.start=NULL, bin.width=NULL, bin.end=NULL,
 
     prop=FALSE, cumul=c("off", "on", "both"), 
     digits.d=NULL, xlab=NULL, ylab=NULL, main=NULL,
@@ -17,25 +17,38 @@ function(x=NULL, data=mydata, n.cat=getOption("n.cat"),
     quiet=getOption("quiet"),
     pdf.file=NULL, pdf.width=5, pdf.height=5, ...)  {
 
+
   # produce actual argument, such as mydata, from an abbreviation
   cumul <- match.arg(cumul)
+  
+  x.name <- deparse(substitute(x))
+  options(xname = x.name)
 
   is.df <- FALSE  # is data frame
 
   if (missing(x)) {
     x.name <- ""  # in case x is missing, i.e., data frame mydata
-      is.df <- TRUE
-      data <- eval(substitute(mydata))
+    is.df <- TRUE
+    data <- eval(substitute(mydata))
   }
-  else {  # get actual variable name before potential call of data$x
-    x.name <- deparse(substitute(x)) 
-    options(xname = x.name)
+
+  else if ( (!grepl(":", x.name) && !grepl(",", x.name)) ) {  # not a var list
     if (exists(x.name, where=1)) if (is.data.frame(x)) {
-       is.df <- TRUE
-       data <- x
+        data <- x
+        is.df <- TRUE
     }
   }
 
+  # proceed here only if x.name is a var list
+  else if (grepl(":", x.name) || grepl(",", x.name) ) {
+    all.vars <- as.list(seq_along(data))
+    names(all.vars) <- names(data)
+    x.col <- eval(substitute(x), envir=all.vars, enclos=parent.frame())
+    data <- data[, x.col]  # create subset data frame
+    is.df <- TRUE
+  }
+
+
   if (!is.df) {
 
     dname <- deparse(substitute(data))
@@ -61,7 +74,7 @@ function(x=NULL, data=mydata, n.cat=getOption("n.cat"),
   if (is.df) hst.data.frame(data, n.cat,
          col.fill, col.stroke, col.bg, col.grid, col.reg,
          over.grid, cex.axis, col.axis, col.ticks, breaks, bin.start, bin.width,
-         prop, cumul, digits.d, xlab, ylab, main, quiet,
+         bin.end, prop, cumul, digits.d, xlab, ylab, main, quiet,
          pdf.width, pdf.height, ...) 
 
   else {
@@ -69,7 +82,7 @@ function(x=NULL, data=mydata, n.cat=getOption("n.cat"),
 
     h <- .hst.main(x.call, col.fill, col.stroke, col.bg, col.grid, col.reg,
          over.grid, cex.axis, col.axis, col.ticks, breaks, bin.start, bin.width,
-         prop, cumul, digits.d, xlab, ylab, main, quiet, ...) 
+         bin.end, prop, cumul, digits.d, xlab, ylab, main, quiet, ...) 
 
     if (!is.null(pdf.file)) {
       dev.off()
