@@ -35,7 +35,7 @@ function (x=mycor,
          col.bg=getOption("col.bg"),
          cex.axis=.85, col.axis="gray30",
          col.ticks="gray30", xy.ticks=TRUE, line.width=1.1,
-         xlab=NULL, ylab="Eigenvalue", main=main, cex=NULL,
+         xlab=NULL, ylab="Eigenvalues", main=main, cex=NULL,
          x.start=NULL, x.end=NULL, y.start=NULL, y.end=NULL,
          time.start=NULL, time.by=NULL, time.reverse=FALSE,
          center.line="off", quiet=TRUE, ...)
@@ -65,7 +65,7 @@ function (x=mycor,
          col.bg=getOption("col.bg"),
          cex.axis=.85, col.axis="gray30",
          col.ticks="gray30", xy.ticks=TRUE, line.width=1.1,
-         xlab=NULL, ylab="Eigenvalue", main=main, cex=NULL,
+         xlab=NULL, ylab="Differences of Successive Eigenvalues", main=main, cex=NULL,
          x.start=NULL, x.end=NULL, y.start=NULL, y.end=NULL,
          time.start=NULL, time.by=NULL, time.reverse=FALSE,
          center.line="off", quiet=TRUE, ...)
