@@ -3,8 +3,8 @@ function(YA, YB, bw1, bw2, Ynm, Xnm, X1nm, X2nm, y.lbl, digits.d, brief,
          n1, m1, s1, n2, m2, s2, df, mdiff, sw, smd, mmd, msmd,
          clpct, tvalue, pvalue, ub, lb, deltaL, deltaU, show.title) {
 
-  dYA <- density(YA, bw1)
-  dYB <- density(YB, bw2)
+  dYA <- suppressWarnings(density(YA, bw1))
+  dYB <- suppressWarnings(density(YB, bw2))
 
   if (!brief) {
     cat("\n\n------ Graphics Smoothing Parameter ------\n\n")
